@@ -6,7 +6,7 @@
 @section Copyright
 
 This file is part of Algol68G - an Algol 68 interpreter.
-Copyright 2001-2015 J. Marcel van der Veer <algol68g@xs4all.nl>.
+Copyright 2001-2016 J. Marcel van der Veer <algol68g@xs4all.nl>.
 
 @section License
 
@@ -35,14 +35,10 @@ Error codes:
 -3	Other error
 **/
 
-#if defined HAVE_CONFIG_H
-#include "a68g-config.h"
-#endif
+#include "a68g.h"
 
 #if defined HAVE_POSTGRESQL
 
-#include "a68g.h"
-
 #define LIBPQ_STRING "PostgreSQL libq"
 #define ERROR_NOT_CONNECTED "not connected to a database"
 #define ERROR_NO_QUERY_RESULT "no query result available"
@@ -55,7 +51,8 @@ Error codes:
 @param p Node in syntax tree.
 **/
 
-void genie_pq_connectdb (NODE_T * p)
+void
+genie_pq_connectdb (NODE_T * p)
 {
   A68_REF ref_string, ref_file, ref_z, conninfo;
   A68_FILE *file;
@@ -123,7 +120,8 @@ void genie_pq_connectdb (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_finish (NODE_T * p)
+void
+genie_pq_finish (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -149,7 +147,8 @@ void genie_pq_finish (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_reset (NODE_T * p)
+void
+genie_pq_reset (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -173,7 +172,8 @@ void genie_pq_reset (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_exec (NODE_T * p)
+void
+genie_pq_exec (NODE_T * p)
 {
   A68_REF ref_z, query;
   A68_REF ref_file;
@@ -205,7 +205,8 @@ void genie_pq_exec (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_parameterstatus (NODE_T * p)
+void
+genie_pq_parameterstatus (NODE_T * p)
 {
   A68_REF ref_z, parameter;
   A68_REF ref_file;
@@ -221,7 +222,7 @@ void genie_pq_parameterstatus (NODE_T * p)
   }
   ref_z = heap_generator (p, MODE (C_STRING), 1 + a68_string_size (p, parameter));
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, (char *) PQparameterStatus (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), parameter)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, (char *) PQparameterStatus (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), parameter)), DEFAULT_WIDTH);
     PUSH_PRIMAL (p, 0, INT);
   } else {
     PUSH_PRIMAL (p, -3, INT);
@@ -233,7 +234,8 @@ void genie_pq_parameterstatus (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_cmdstatus (NODE_T * p)
+void
+genie_pq_cmdstatus (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -250,7 +252,7 @@ void genie_pq_cmdstatus (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQcmdStatus (RESULT (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQcmdStatus (RESULT (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -263,7 +265,8 @@ void genie_pq_cmdstatus (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_cmdtuples (NODE_T * p)
+void
+genie_pq_cmdtuples (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -280,7 +283,7 @@ void genie_pq_cmdtuples (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQcmdTuples (RESULT (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQcmdTuples (RESULT (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -293,7 +296,8 @@ void genie_pq_cmdtuples (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_ntuples (NODE_T * p)
+void
+genie_pq_ntuples (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -317,7 +321,8 @@ void genie_pq_ntuples (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_nfields (NODE_T * p)
+void
+genie_pq_nfields (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -341,7 +346,8 @@ void genie_pq_nfields (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_fname (NODE_T * p)
+void
+genie_pq_fname (NODE_T * p)
 {
   A68_INT a68g_index;
   int upb;
@@ -367,7 +373,7 @@ void genie_pq_fname (NODE_T * p)
     exit_genie (p, A68_RUNTIME_ERROR);
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQfname (RESULT (file), VALUE (&a68g_index) - 1), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQfname (RESULT (file), VALUE (&a68g_index) - 1), DEFAULT_WIDTH);
     STRPOS (file) = 0;
   }
   PUSH_PRIMAL (p, 0, INT);
@@ -378,7 +384,8 @@ void genie_pq_fname (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_fnumber (NODE_T * p)
+void
+genie_pq_fnumber (NODE_T * p)
 {
   A68_REF ref_z, name;
   A68_REF ref_file;
@@ -411,7 +418,8 @@ void genie_pq_fnumber (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_fformat (NODE_T * p)
+void
+genie_pq_fformat (NODE_T * p)
 {
   A68_INT a68g_index;
   int upb;
@@ -444,7 +452,8 @@ void genie_pq_fformat (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_getvalue (NODE_T * p)
+void
+genie_pq_getvalue (NODE_T * p)
 {
   A68_INT row, column;
   char *str;
@@ -483,7 +492,7 @@ void genie_pq_getvalue (NODE_T * p)
     exit_genie (p, A68_RUNTIME_ERROR);
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -496,7 +505,8 @@ void genie_pq_getvalue (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_getisnull (NODE_T * p)
+void
+genie_pq_getisnull (NODE_T * p)
 {
   A68_INT row, column;
   int upb;
@@ -536,7 +546,8 @@ void genie_pq_getisnull (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-static char *pq_edit (char *str)
+static char *
+pq_edit (char *str)
 {
   if (str == NULL) {
     return ("");
@@ -591,7 +602,8 @@ static char *pq_edit (char *str)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_errormessage (NODE_T * p)
+void
+genie_pq_errormessage (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -615,7 +627,7 @@ void genie_pq_errormessage (NODE_T * p)
     } else {
       bufcpy (str, "no error message available", BUFFER_SIZE);
     }
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -628,7 +640,8 @@ void genie_pq_errormessage (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_resulterrormessage (NODE_T * p)
+void
+genie_pq_resulterrormessage (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -656,7 +669,7 @@ void genie_pq_resulterrormessage (NODE_T * p)
     } else {
       bufcpy (str, "no error message available", BUFFER_SIZE);
     }
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -669,7 +682,8 @@ void genie_pq_resulterrormessage (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_db (NODE_T * p)
+void
+genie_pq_db (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -682,7 +696,7 @@ void genie_pq_db (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQdb (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQdb (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -695,7 +709,8 @@ void genie_pq_db (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_user (NODE_T * p)
+void
+genie_pq_user (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -708,7 +723,7 @@ void genie_pq_user (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQuser (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQuser (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -721,7 +736,8 @@ void genie_pq_user (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_pass (NODE_T * p)
+void
+genie_pq_pass (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -734,7 +750,7 @@ void genie_pq_pass (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQpass (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQpass (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -747,7 +763,8 @@ void genie_pq_pass (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_host (NODE_T * p)
+void
+genie_pq_host (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -760,7 +777,7 @@ void genie_pq_host (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQhost (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQhost (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -773,7 +790,8 @@ void genie_pq_host (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_port (NODE_T * p)
+void
+genie_pq_port (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -786,7 +804,7 @@ void genie_pq_port (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQport (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQport (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -799,7 +817,8 @@ void genie_pq_port (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_tty (NODE_T * p)
+void
+genie_pq_tty (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -812,7 +831,7 @@ void genie_pq_tty (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQtty (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQtty (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -825,7 +844,8 @@ void genie_pq_tty (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_options (NODE_T * p)
+void
+genie_pq_options (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -838,7 +858,7 @@ void genie_pq_options (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    * DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQoptions (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQoptions (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -851,7 +871,8 @@ void genie_pq_options (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_protocolversion (NODE_T * p)
+void
+genie_pq_protocolversion (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -875,7 +896,8 @@ void genie_pq_protocolversion (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_serverversion (NODE_T * p)
+void
+genie_pq_serverversion (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -899,7 +921,8 @@ void genie_pq_serverversion (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_socket (NODE_T * p)
+void
+genie_pq_socket (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
@@ -923,7 +946,8 @@ void genie_pq_socket (NODE_T * p)
 @param p Node in syntax tree.
 **/
 
-void genie_pq_backendpid (NODE_T * p)
+void
+genie_pq_backendpid (NODE_T * p)
 {
   A68_REF ref_file;
   A68_FILE *file;
